pub struct ExtraConfig {
pub attribute_types: Vec<Type>,
pub yivi: Option<YiviConfig>,
pub auth_window: Duration,
pub max_attr_types_per_req: usize,
pub attr_key_secret: Option<B64UU>,
pub decap_key: Option<DecapKeyBytes>,
}Fields
attribute_types: Vec<Type>yivi: Option<YiviConfig>Yivi configuration. If None, yivi is not supported.
auth_window: DurationAuthentication must be completed within this timeframe
formatted as string understood by humantime::parse_duration such as 1 week.
max_attr_types_per_req: usizeMaximum number of attribute types a single api::auths::AuthStartReq may request,
and the maximum number of alternatives allowed per attribute type
(see api::auths::AuthStartReq::attr_type_choices).
Bounds the work an anonymous authentication-start request can trigger.
attr_key_secret: Option<B64UU>Used to derive attribute keys (see api::auths::AttrKeysEP)
Randomly generated when not set. When changed, users loose access to all data stored at PHC.
decap_key: Option<DecapKeyBytes>Hybrid post-quantum kem decapsulation key, used to establish a shared secret
with pubhubs central. Randomly generated when not set.
Generate using cargo run tools generate decap-key
Implementations
Sourceimpl ExtraConfig
impl ExtraConfig
Sourcepub(super) fn filter_attribute_types(&mut self)
pub(super) fn filter_attribute_types(&mut self)
Removes the attr::SourceDetailss of unsupported sources from
attribute_types.