pub struct YiviConfig {
pub requestor_url: UrlPwa,
pub requestor_creds: Credentials<SigningKey>,
pub server_name: String,
pub server_key: Option<VerifyingKey>,
pub chained_sessions: ChainedSessionsConfig,
pub card: CardConfig,
}Fields
requestor_url: UrlPwaWhere can the Yivi server trusted by the authentication server be reached by the hub client for starting disclosure requests?
requestor_creds: Credentials<SigningKey>server_name: StringWhat server name to expect in signed session results
server_key: Option<VerifyingKey>Verify signed session results using this key. If not set the key is retrieved from the yivi server.
chained_sessions: ChainedSessionsConfigFine-tune handling of chained sessions, see
api::auths::AuthStartReq::yivi_chained_session.
card: CardConfigConfiguration of the pubhubs card issued by the authentication server
Implementations
Sourceimpl YiviConfig
impl YiviConfig
pub fn server_creds(&self) -> Credentials<VerifyingKey>